@@ -2,7 +2,7 @@
 ASGI App using dataclasses module for request/response objects
 """
 
-__version__ = '0.26.0'
+__version__ = '0.27.1'
 
 from apidaora.app import appdaora
 from apidaora.bodies import GZipFactory
@@ -25,7 +25,7 @@ from apidaora.responses import (
     not_found,
     text,
 )
-from apidaora.route.decorator import route
+from apidaora.route.decorator import RoutedControllerTypeHint, route
 
 
 __all__ = [
@@ -47,4 +47,5 @@ __all__ = [
     'Request',
     'ClassController',
     'BackgroundTaskMiddleware',
+    'RoutedControllerTypeHint',
 ]
